@@ -360,7 +360,7 @@ $Conf{CgiDir}      = '/usr/share/backuppc/cgi-bin';
 # are really running as user $Conf{BackupPCUser}.  If this flag is set
 # and the effective user id (euid) differs from $Conf{BackupPCUser}
 # then both scripts exit with an error.  This catches cases where
-# BackupPC might be accidently started as root or the wrong user,
+# BackupPC might be accidentally started as root or the wrong user,
 # or if the CGI script is not installed correctly.
 #
 $Conf{BackupPCUserVerify} = 1;
@@ -457,19 +457,24 @@ $Conf{IncrPeriod} = 0.97;
 #     efficient to view or restore older backups.
 #
 #   - more importantly, in V4+, deleting backups is done based on Fill/Unfilled,
-#     not whether the original backup was full/incremental.  If there aren't
-#     any filled backups (other than the most recent), then the FillKeepPeriod
-#     settings won't have any effect.
+#     not whether the original backup was full/incremental.  If there aren't any
+#     filled backups (other than the most recent), then the $Conf{FullKeepCnt}
+#     and related settings won't have any effect.
 #
 $Conf{FillCycle} = 0;
 
 #
 # Number of filled backups to keep.  Must be >= 1.
 #
+# The most recent backup (which is always filled) doesn't count when
+# checking $Conf{FullKeepCnt}.  So if you specify $Conf{FullKeepCnt} = 1
+# then that means keep one full backup in addition to the most recent
+# backup (which might be a filled incr or full).
+#
 # Note: Starting in V4+, deleting backups is done based on Fill/Unfilled,
-# not whether the original backup was full/incremental.  
-# reasons these parameters continue to be called FullKeepCnt, rather than
-# FilledKeepCnt.  If $Conf{FillCycle} is 0, then full backups continue
+# not whether the original backup was full/incremental. For backward
+# compatibility, these parameters continue to be called FullKeepCnt, rather
+# than FilledKeepCnt.  If $Conf{FillCycle} is 0, then full backups continue
 # to be filled, so the terms are interchangeable.  For V3 backups,
 # the expiry settings have their original meanings.
 #
@@ -552,7 +557,7 @@ $Conf{FullKeepCnt} = 1;
 # full backups to exceed $Conf{FullAgeMax}.
 #
 $Conf{FullKeepCntMin} = 1;
-$Conf{FullAgeMax}     = 90;
+$Conf{FullAgeMax}     = 180;
 
 #
 # Number of incremental backups to keep.  Must be >= 1.
@@ -826,7 +831,7 @@ $Conf{BackupZeroFilesIsFatal} = 1;
 $Conf{XferMethod} = 'smb';
 
 #
-# Level of verbosity in Xfer log files.  0 means be quiet, 1 will give
+# Level of verbosity in Xfer log files.  0 means be quiet, 1
 # will give one line per file, 2 will also show skipped files on
 # incrementals, higher values give more output.
 #
@@ -943,7 +948,7 @@ $Conf{SmbClientPath} = '/usr/bin/smbclient';
 #
 $Conf{SmbClientFullCmd} = '$smbClientPath \\\\$host\\$shareName'
 	    . ' $I_option -U $userName -E -d 1'
-            . ' -c tarmode\\ full -Tc$X_option - $fileList';
+            . ' -c tarmode\\ full -mSMB3 -Tc$X_option - $fileList';
 
 #
 # Command to run smbclient for an incremental dump.
@@ -957,7 +962,7 @@ $Conf{SmbClientFullCmd} = '$smbClientPath \\\\$host\\$shareName'
 #
 $Conf{SmbClientIncrCmd} = '$smbClientPath \\\\$host\\$shareName'
 	    . ' $I_option -U $userName -E -d 1'
-	    . ' -c tarmode\\ full -TcN$X_option $timeStampFile - $fileList';
+	    . ' -c tarmode\\ full -mSMB3 -TcN$X_option $timeStampFile - $fileList';
 
 #
 # Command to run smbclient for a restore.
@@ -975,7 +980,7 @@ $Conf{SmbClientIncrCmd} = '$smbClientPath \\\\$host\\$shareName'
 #
 $Conf{SmbClientRestoreCmd} = '$smbClientPath \\\\$host\\$shareName'
             . ' $I_option -U $userName -E -d 1'
-            . ' -c tarmode\\ full -Tx -';
+            . ' -c tarmode\\ full -mSMB3 -Tx -';
 
 ###########################################################################
 # Tar Configuration
@@ -1239,6 +1244,8 @@ $Conf{RsyncArgs} = [
             '--links',
             '--hard-links',
             '--delete',
+            '--delete-excluded',
+            '--one-file-system',
             '--partial',
             '--log-format=log: %o %i %B %8U,%8G %9l %f%L',
             '--stats',
@@ -1656,11 +1663,11 @@ $Conf{CompressLevel} = 5;
 #
 # Note that stdout buffering combined with huge files being backed up
 # could cause longish delays in the output from smbclient that
-# BackupPC_dump sees, so in rare cases you might want to increase
+# BackupPC_dump sees, so in some cases you might want to increase
 # this value.
 #
-# Despite the name, this parameter sets the timeout for all transport
-# methods (tar, smb etc).
+# For rsync, this is passed onto rsync_bpc using the --timeout argument,
+# which is based on any I/O, so you could likely reduce this value.
 #
 $Conf{ClientTimeout} = 72000;
 
@@ -1790,16 +1797,25 @@ $Conf{UserCmdCheckStatus} = 0;
 # Override the client's hostname.  This allows multiple clients
 # to all refer to the same physical host.  This should only be
 # set in the per-PC config file and is only used by BackupPC at
-# the last moment prior to generating the command used to backup
-# that machine (ie: the value of $Conf{ClientNameAlias} is invisible
-# everywhere else in BackupPC).  The setting can be a hostname or
-# IP address, eg:
+# the last moment prior to checking the host is alive, and generating
+# the command used to backup # that machine (ie: the value of
+# $Conf{ClientNameAlias} is invisible everywhere else in BackupPC).
+# The setting can be a hostname or IP address, eg:
 #
 #         $Conf{ClientNameAlias} = 'realHostName';
 #         $Conf{ClientNameAlias} = '192.1.1.15';
 #
-# will cause the relevant smb/tar/rsync backup/restore commands to be
-# directed to realHostName, not the client name.
+# which will cause the relevant smb/tar/rsync backup/restore commands
+# to be directed to realHostName or the IP address, not the client name.
+#
+# It can also be an array, to allow checking (in order) of several
+# host names or IP addresses that refer to the same host.  For example,
+# if your client has a wired and wireless connection you could set:
+#
+#         $Conf{ClientNameAlias} = ['hostname-lan', 'hostname-wifi'];
+#
+# If hostname-lan is alive, it will be used for the backup/restore.
+# If not, the next name (hostname-wifi) is tested.
 #
 # Note: this setting doesn't work for hosts with DHCP set to 1.
 #
@@ -2014,7 +2030,7 @@ $Conf{RrdToolPath} = '/usr/bin/rrdtool';
 # Language to use.  See lib/BackupPC/Lang for the list of supported
 # languages, which include English (en), French (fr), Spanish (es),
 # German (de), Italian (it), Dutch (nl), Polish (pl), Portuguese
-# Brazilian (pt_br) and Chinese (zh_CH).
+# Brazilian (pt_br) and Chinese (zh_CN).
 #
 # Currently the Language setting applies to the CGI interface and email
 # messages sent to users.  Log files and other text are still in English.
@@ -2083,12 +2099,12 @@ $Conf{CgiNavBarLinks} = [
     },
     {
         link  => "https://backuppc.github.io/backuppc",
-        name  => "Github",           # displays literal "Github"
+        name  => "Homepage",         # displays literal "Homepage"
     },
 ];
 
 #
-# Hilight colors based on status that are used in the PC summary page.
+# Highlight colors based on status that are used in the PC summary page.
 #
 $Conf{CgiStatusHilightColor} = {
     Reason_backup_failed           => '#ffcccc',
@@ -2229,6 +2245,7 @@ $Conf{CgiUserConfigEdit} = {
         RestorePreUserCmd         => 0,
         RsyncArgs                 => 1,
         RsyncArgsExtra            => 1,
+        RsyncBackupPCPath         => 0,
         RsyncClientPath           => 0,
         RsyncdAuthRequired        => 1,
         RsyncdClientPort          => 1,
@@ -2240,6 +2257,7 @@ $Conf{CgiUserConfigEdit} = {
         RsyncSshArgs              => 1,
         SmbClientFullCmd          => 0,
         SmbClientIncrCmd          => 0,
+        SmbClientPath             => 0,
         SmbClientRestoreCmd       => 0,
         SmbShareName              => 1,
         SmbSharePasswd            => 1,
